from setuptools import setup

setup(name='jbird',
      version='0.0.1',
      description='JSON NoSQL database',
      packages=['jbird'],
      author_email='notdepot@gmail.com',
      zip_safe=False)